function A = assemble_P1operator(grid, localAssembler, quadrature)
% assemble_P1operator - Assemble a bilinear form for P1 finite elements
%                       as matrix.
%
% Usage:                A = assemble_P1operator(grid, localAssembler, quadrature)
%
% Arguments:            simplex        - Grid structure
%                       localAssembler - Local assembler as function reference
%                       quadrature     - Quadrature rule


P1Basis = basis(1);

n = size(grid.nodes, 2);

A = spalloc(n, n, 10*n);

for i = 1:size(grid.elements, 2)
    nodes = grid.elements(1:3,i);
    T = grid.nodes(1:2, nodes);
    localA = localAssembler(T, P1Basis, quadrature);
    A(nodes, nodes) = A(nodes, nodes) + localA;
end
