function A = assemble_P2operator(grid, localAssembler, quadrature, P2Basis)
% assemble_P2operator - Assemble a bilinear form for P2 finite elements
%                       as matrix.
%
% Usage:                A = assemble_P1operator(grid, localAssembler, quadrature)
%
% Arguments:            simplex        - Grid structure
%                       localAssembler - Local assembler as function reference
%                       quadrature     - Quadrature rule
%                       P2Basis        - Basis for P2 finite elements (optional)

if (nargin<4)
    P2Basis = basis(2);
end

n_nodes = size(grid.nodes, 2);
n_edges = size(grid.edges, 2);
n_elements = size(grid.elements, 2);

n = n_nodes + n_edges;

A = spalloc(n, n, 10*n);

for i = 1:n_elements
    nodes = grid.elements(1:3,i);
    edges = grid.elements(4:6,i);

    T = grid.nodes(1:2, nodes);
    localA = localAssembler(T, P2Basis, quadrature);

    indices = [nodes; edges+n_nodes];
    A(indices, indices) = A(indices, indices) + localA;
end

