function b = assemble_rhs(grid, f, quadrature, basis)

if (nargin<4)
    basis = basis(1);
end

if (basis.size==3)
    p=1;
else
    p=2;
end

n_nodes = size(grid.nodes, 2);
n_edges = size(grid.edges, 2);
n_elements = size(grid.elements, 2);

if (p==1)
    n = n_nodes;
else
    n = n_nodes+n_edges;
end

b = zeros(n,1);
for i = 1:n_elements
    nodes = grid.elements(1:3,i);
    edges = grid.elements(4:6,i);

    if (p==1)
        indices = nodes;
    else
        indices = [nodes; edges+n_nodes];
    end

    simplex = grid.nodes(1:2, nodes);

    T(:,1) = simplex(:,2) - simplex(:,1);
    T(:,2) = simplex(:,3) - simplex(:,1);

    integrationElement = abs(det(T));

    for q = 1:quadrature.size

        P = quadrature.points(:,q);
        w = quadrature.weights(q)*integrationElement;

        p_world = T*P+ simplex(:,1);
        f_p = f(p_world);

        for i = (1:basis.size)
            lambda_p = basis.value(P,i);

            b(indices(i)) = b(indices(i)) + f_p*lambda_p*w;
        end
    end
end

